from setuptools import setup

setup(name='distributions_mango',
      version='0.1',
      description='Gaussian distributions and Binomial Distributions',
      packages=['distributions_mango'],
      zip_safe=False)
